### Name: bnlearn-package
### Title: Bayesian network structure learning.
### Aliases: bnlearn-package bnlearn
### Keywords: package

### ** Examples

library(bnlearn)
data(learning.test)

## Simple learning
# first try the Grow-Shrink algorithm
res = gs(learning.test)
# plot the network structure.
plot(res)
# now try the Incremental Association algorithm.
res2 = iamb(learning.test)
# plot the new network structure.
plot(res2)
# the network structures seem to be identical, don't they?
compare(res, res2)
# [1] TRUE
# how many tests each of the two algorithms used?
res$learning$ntests
# [1] 41
res2$learning$ntests
# [1] 50
# and the unoptimized implementation of these algorithms?
## Not run: gs(learning.test, optimized = FALSE)$learning$ntests
# [1] 90
## Not run: iamb(learning.test, optimized = FALSE)$learning$ntests
# [1] 116

## Greedy search
res = hc(learning.test)
plot(res)

## Another simple example (Gaussian data)
data(gaussian.test)
# first try the Grow-Shrink algorithm
res = gs(gaussian.test)
plot(res)

## Blacklist and whitelist use
# the arc B - F should not be there?
blacklist = data.frame(from = c("B", "F"), to = c("F", "B"))
blacklist
#   from to
# 1    B  F
# 2    F  B
res3 = gs(learning.test, blacklist = blacklist)
plot(res3)
# force E - F direction (E -> F).
whitelist = data.frame(from = c("E"), to = c("F"))
whitelist
#   from to
# 1    E  F
res4 = gs(learning.test, whitelist = whitelist)
plot(res4)
# use both blacklist and whitelist.
res5 = gs(learning.test, whitelist = whitelist, blacklist = blacklist)
plot(res5)

## Debugging
# use the debugging mode to see the learning algorithms
# in action.
res = gs(learning.test, debug = TRUE)
res = hc(learning.test, debug = TRUE)
# log the learning process for future reference.
## Not run: 
##D sink(file = "learning-log.txt")
##D res = gs(learning.test, debug = TRUE)
##D sink()
## End(Not run)
# if something seems wrong, try the unoptimized version
# in strict mode (inconsistencies trigger errors):
## Not run: 
##D res = gs(learning.test, optimized = FALSE, strict = TRUE, debug = TRUE)
## End(Not run)
# or disable strict mode to let the algorithm fix errors on the fly:
## Not run: 
##D res = gs(learning.test, optimized = FALSE, strict = FALSE, debug = TRUE)
## End(Not run)




